/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
#include "config/host.h"

#include "boost_assert_handler.h"

#include <limits>

using namespace std;

//-----------------------------------------------------------------------------
// Host
//-----------------------------------------------------------------------------

/**
 * @brief Parameterized constructor.
 *
 * @param address The host address
 */
Host::Host( string address ) :
    Address( address ),
    Port( 0 ),
    SourceNetworkInterface( "" ),
    ProtocolList(),
    IntervalInSec( 0 )
{
}

/**
 * @brief Destructor.
 */
Host::~Host()
{
}

/**
 * @return A string representing the host address.
 */
string Host::get_address() const
{
    return Address;
}

/**
 * @param address A string representing the host address.
 */
void Host::set_address( const string &address )
{
    BOOST_ASSERT( !address.empty() );

    this->Address = address;
}

/**
 * @return The destination port number to ping the host.
 */
uint16_t Host::get_port() const
{
    return Port;
}

/**
 * @param port The destination port number to ping the host.
 */
void Host::set_port( const uint16_t port )
{
    BOOST_ASSERT( ( 0 < port ) && ( port < numeric_limits<uint16_t>::max() ) );

    this->Port = port;
}

/**
 * @return The network interface from where the pings will depart.
 */
string Host::get_source_network_interface() const
{
    return SourceNetworkInterface;
}

/**
 * @param source_network_interface The network interface from where the pings will depart.
 */
void Host::set_source_network_interface(
        const string &source_network_interface
)
{
    SourceNetworkInterface = source_network_interface;
}

/**
 * @return The list of protocols used to ping this host.
 */
PingProtocolList Host::get_ping_protocol_list() const
{
    return ProtocolList;
}

/**
 * @param ping_protocol The list of protocols to be used to ping this host.
 */
void Host::set_ping_protocol_list( const PingProtocolList &ping_protocol_list )
{
    BOOST_ASSERT( 0 < ping_protocol_list.size() );
    BOOST_ASSERT( (PingProtocol_First <= ping_protocol_list.front()) && (ping_protocol_list.front() <= PingProtocol_Last) );
    BOOST_ASSERT( (PingProtocol_First <= ping_protocol_list.back()) && (ping_protocol_list.back() <= PingProtocol_Last) );

    this->ProtocolList = ping_protocol_list;
}

/**
 * @return The interval between each ping to the host.
 */
int Host::get_interval_in_sec() const
{
    return IntervalInSec;
}

/**
 * @param interval_in_sec The interval between each ping to the host.
 */
void Host::set_interval_in_sec( const int interval_in_sec )
{
    BOOST_ASSERT( ( 0 < interval_in_sec ) && ( interval_in_sec < numeric_limits<int>::max() ) );

    this->IntervalInSec = interval_in_sec;
}
